@@ -146,7 +146,6 @@ function calculate_pair => sub {
 
 function calculate_run => sub {
 	my ($self, $score, $card) = @_; 
-use Data::Dumper;
 	my @cards = map { $_->card } @{$self->cards};
 	my @values = map { $_->run_value } (@cards, $card);
 	my $length = scalar @values - 1;
@@ -164,7 +163,6 @@ use Data::Dumper;
 			}
 		}
 		if ($match) {
-warn Dumper 'ALLREADY HAVE A TEST';
 			$score->run = $match;
 			last;
 		}
